#
# spec file for package micropython
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           micropython
Version:        1.22.0
Release:        2.3
Summary:        Implementation of Python 3 with very low memory footprint
License:        MIT
URL:            https://micropython.org/
Source:         https://micropython.org/resources/source/%{name}-%{version}.tar.xz
BuildRequires:  openssl
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(libffi)
Recommends:     micropython-lib
ExcludeArch:    %{ix86} %{arm} ppc64 ppc64le

%description
A lean and efficient Python implementation for microcontrollers and constrained systems

%prep
%autosetup -p1

sed -i -e "s:/usr/lib/micropython:%{_prefix}/lib/micropython:g" "ports/unix/main.c"

%define make_flags V=1 MICROPY_PY_BTREE=0 MICROPY_PY_USSL=0

%build
export CFLAGS="%optflags -Wno-dangling-pointer"
%make_build -C mpy-cross
%make_build -C ports/unix STRIP=true

%install
install -d %{buildroot}%{_bindir}
install -t %{buildroot}%{_bindir} ports/unix/build-standard/micropython

%check
%ifnarch x86_64
# 2 tests fail: float_parse float_parse_doubleprec
# https://github.com/micropython/micropython/pull/6024
rm -f tests/float/float_parse.py
rm -f tests/float/float_parse_doubleprec.py
%endif
export MICROPY_CPYTHON3=python3
make -C ports/unix PYTHON=%{_bindir}/python3 V=1 test

%files
%license LICENSE
%doc docs/unix/*
%{_bindir}/micropython

%changelog
* Mon Jan 15 2024 Andreas Schwab <schwab@suse.de>
- Build with %%optflags
* Mon Jan  8 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.22.0:
  * https://github.com/micropython/micropython/releases/tag/v1.22.0
  * objslice: validate that the argument to indices() is an integer
    (CVE-2023-7158, bsc#1218446)
* Fri Apr 28 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.20.0:
  * https://github.com/micropython/micropython/releases/tag/v1.20.0
- Remove 32572439984e5640c6af46fbe7c27400c30112ce.patch, included.
- Disable warning, since it is treated as an error.
* Tue Mar 28 2023 Dirk Müller <dmueller@suse.com>
- add 32572439984e5640c6af46fbe7c27400c30112ce.patch
* Tue Oct 11 2022 Andreas Schwab <schwab@suse.de>
- Suppress stripping of binary
- Run tests everywhere with just the problematic ones suppressed
* Sat Jul  2 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.19.1:
  * https://github.com/micropython/micropython/releases/tag/v1.19
* Wed Feb  2 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 1.18: full changelog available at
  https://github.com/micropython/micropython/releases/tag/v1.18
* Sun Jan 16 2022 Dirk Müller <dmueller@suse.com>
- avoid spec-cleaner messing it up
* Fri Sep 24 2021 Matej Cepl <mcepl@suse.com>
- Update to 1.17:
  The release notes are REALLY long, so please go to
  https://github.com/micropython/micropython/releases/tag/v1.17
  to read them.
- Remove already upstreamed patch fix-uasyncio_heaplock-test.patch.
* Mon Aug  2 2021 Danilo Spinella <danilo.spinella@suse.com>
- Add fix-uasyncio_heaplock-test.patchto fix uasyncio_heaplock
  test (originally from gh#micropython/micropython#7449)
* Tue Jul 27 2021 Matej Cepl <mcepl@suse.com>
- Remove unnecessary dependency on python2
* Fri Jul 23 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to v1.16:
  * Full release notes: https://github.com/micropython/micropython/releases/tag/v1.16
  * New command-line tool called "mpremote"
  * Unix port updates:
  - modffi: use a union for passing/returning FFI values
  - main: increase stack limit on ARM architectures
  - modffi: fix conversion between Python integers and ffi types
  - fix build on arm64-darwin due to integer cast
* Fri May  7 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.15:
  * Full release notes: https://github.com/micropython/micropython/releases/tag/v1.15
  * Unix port updates:
  - mpbtstackport_common: implement mp_bluetooth_hci_active
  - moduselect: don't allow both posix and non-posix configurations
  - improve command line argument processing
  - main: make static variable that's potentially clobbered by longjm
- Remove patch fix-aarch64-builds.patch
- Exclude ppc64 and ppc64le as build fails for those architectures
* Sat Apr 17 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Add patch fix-aarch64-builds.patch
* Fri Feb  5 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to v1.14:
  * Full release notes: https://github.com/micropython/micropython/releases/tag/v1.14
  * Unix port updates:
  - Makefile: always enable -f*-sections regardless of DEBUG setting
  - implement BLE H4 HCI UART for btstack/nimble
  - implement mp_hal_time_ns using gettimeofday
  - variants: enable MICROPY_DEBUG_PARSE_RULE_NAME on coverage build
  - mpconfigport.h: enable MICROPY_PY_DELATTR_SETATTR
  - enable more warnings
  - support building C++ code
  - Makefile: move coverage.c and coveragecpp.cpp to coverage variant
  - handle pending events/scheduler in MICROPY_EVENT_POLL_HOOK
  - make mp_hal_delay_ms run MICROPY_EVENT_POLL_HOOK
  - modtime: fix time() precision on unix ports with non-double floats
* Fri Jan 29 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Drop _service file
- Exclude %%{arm} as lots of tests fail
* Wed Jan 27 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Cleanup package and enable tests
* Sun Sep  6 2020 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 1.13: full changelog available at https://github.com/micropython/micropython/releases/tag/v1.13
* Thu Dec 26 2019 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 1.12: full changelog available at https://github.com/micropython/micropython/releases/tag/v1.12
- Build mpy-cross
* Sun Jun 23 2019 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 1.11: full changelog at https://github.com/micropython/micropython/releases/tag/v1.11
* Sat Jan 26 2019 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 1.10: full changelog at https://github.com/micropython/micropython/releases/tag/v1.10
* Thu Dec  6 2018 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Use _service
* Fri May 11 2018 jaime.marquinez.ferrandiz@fastmail.net
- Update to 1.9.4: full changelog at https://github.com/micropython/micropython/releases/tag/v1.9.4
* Fri Jan 12 2018 jaime.marquinez.ferrandiz@fastmail.net
- Update to 1.9.3: full changelog at https://github.com/micropython/micropython/releases/tag/v1.9.3
